@@ -8,7 +8,7 @@ import re
 from dataclasses import dataclass
 
 import pkg_resources
-pkg_resources.require("lark==1.1.2")
+pkg_resources.require("lark==0.12.0")
 from lark import Lark, Tree
 
 
@@ -42,7 +42,7 @@ grammar_file = os.path.join(os.path.dirname(__file__), "cairo.ebnf")
 parser = Lark(
     open(grammar_file, "r").read(),
     start="cairo_file",
-    lexer="basic",
+    lexer="standard",
     parser="lalr",
     propagate_positions=True
 )
@@ -63,7 +63,6 @@ def get_struct_members(tree: Tree):
     members = []
     for child in tree.children:
         if isinstance(child, Tree) and child.data == 'commented_code_element':
-
             name = child.children[0].children[0].children[0].children[0].value
             original_type = child.children[0].children[0].children[1].data
             if original_type == 'type_struct':
@@ -71,7 +70,7 @@ def get_struct_members(tree: Tree):
             elif original_type == 'type_felt':
                 original_type = 'string'
 
-            type_hint = parse_parameter_hint(child.children[1].value if child.children[1] is not None else None)
+            type_hint = parse_parameter_hint(child.children[1].value if len(child.children) > 1 and child.children[1] is not None else None)
             type = type_hint if type_hint is not None else original_type
 
             members.append(Parameter(
@@ -147,6 +146,7 @@ def generate(inputfile, outputfile):
     fileContents = input.read()
     result = parse(fileContents)
     output = open(outputfile, "a")
+    output.truncate(0)
     output.write(result)
     input.close()
     output.close()
